@@ -14,7 +14,6 @@ from django.core import checks
 from django.core.files import File
 from django.core.files.storage import Storage
 from django.db import models
-from django.db.models.base import ModelBase
 from django.db.models.fields.files import FieldFile
 from django.db.models.functions import Coalesce
 from django.template import loader
@@ -47,6 +46,7 @@ from .fields.base import DynamicStorageFileField
 from .fields.collection import ContentItemRelation
 from .image import VariationalFileField
 from .mixins import BacklinkModelMixin, EditableResourceMixin
+from .query import PolymorphicResourceManager
 
 __all__ = [
     "CollectionItemBase",
@@ -102,7 +102,7 @@ class ItemTypesDescriptor:
         return item_types
 
 
-class CollectionMeta(NoPermissionsMetaBase, ModelBase):
+class CollectionMeta(NoPermissionsMetaBase, models.base.ModelBase):
     """
     Хак, при котором вместо наследования создаются прокси-модели,
     если явно не указано обратное.
@@ -333,6 +333,8 @@ class CollectionItemBase(EditableResourceMixin, PolymorphicModel, Resource, meta
         editable=False
     )
 
+    objects = PolymorphicResourceManager()
+
     class Meta:
         # Используется обратный порядок полей в составном индексе,
         # т.к. селективность поля collection_id выше, а для поля
@@ -341,6 +343,13 @@ class CollectionItemBase(EditableResourceMixin, PolymorphicModel, Resource, meta
         verbose_name = _("item")
         verbose_name_plural = _("items")
 
+    class ResourceMeta:
+        required_fields = [
+            "polymorphic_ctype_id",
+            "collection_content_type_id",
+            "type"  # required for get_item_type_field()
+        ]
+
     @classmethod
     def check(cls, **kwargs):
         return [
@@ -434,7 +443,7 @@ class CollectionItemBase(EditableResourceMixin, PolymorphicModel, Resource, meta
 
     def get_collection_class(self) -> Type[CollectionBase]:
         # Прямое обращение к полю `self.collection_content_type` дёргает БД.
-        # Вместо него используется метод `get_for_id()` класса ContentType,
+        # Вместо этого используется метод `get_for_id()` класса ContentType,
         # который использует общий кэш.
         # (!) Если класс модели для указанного ContentType удалён, то
         # метод вернёт None.
@@ -585,7 +594,7 @@ class FileItemBase(FilePreviewMixin, CollectionFileItemBase):
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
-            self.display_name = self.basename
+            self.display_name = self.resource_name
         super().save(*args, **kwargs)
 
     def get_file_folder(self) -> str:
@@ -604,7 +613,7 @@ class FileItemBase(FilePreviewMixin, CollectionFileItemBase):
         return cls._meta.get_field("file")
 
     def get_caption(self):
-        name = self.display_name or self.basename
+        name = self.display_name or self.resource_name
         if self.extension:
             return "{}.{}".format(name, self.extension)
         return name
@@ -636,7 +645,7 @@ class SVGItemBase(SVGFileResourceMixin, CollectionFileItemBase):
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
-            self.display_name = self.basename
+            self.display_name = self.resource_name
         super().save(*args, **kwargs)
 
     def get_file_folder(self) -> str:
@@ -655,7 +664,7 @@ class SVGItemBase(SVGFileResourceMixin, CollectionFileItemBase):
         return cls._meta.get_field("file")
 
     def get_caption(self):
-        name = self.display_name or self.basename
+        name = self.display_name or self.resource_name
         if self.extension:
             return "{}.{}".format(name, self.extension)
         return name
