@@ -2,7 +2,7 @@ from typing import IO, Any, Dict, List, Tuple, Union
 
 from django.core.files import File
 
-__all__ = ['FileLike', 'Limitations', 'VariationConfig']
+__all__ = ["FileLike", "Limitations", "VariationConfig"]
 
 FileLike = Union[IO, File]
 VariationConfig = Dict[str, Any]
