@@ -13,7 +13,7 @@ def get_model_class(content_type_id: int, base_class: Type[T]) -> Type[T]:
     Получение класса модели загружаемого файла по ContentType ID.
     """
     try:
-        content_type = ContentType.objects.get(pk=content_type_id)
+        content_type = ContentType.objects.get_for_id(content_type_id)
     except ContentType.DoesNotExist:
         raise exceptions.InvalidContentType(content_type_id)
 
@@ -29,8 +29,6 @@ def get_instance(model_class: Type[models.Model], pk: Any) -> models.Model:
     Получение экземпляра модели загружаемого файла.
     """
     try:
-        instance_id = int(pk)
+        return model_class._default_manager.get(pk=pk)
     except (ValueError, TypeError):
         raise exceptions.InvalidObjectId(pk)
-
-    return model_class._default_manager.get(pk=instance_id)
